==> istio-model-v1beta1-5.12.4-sources.jar: io/fabric8/istio/api/networking/v1beta1/ServerTLSSettingsBuilder.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ServerTLSSettingsBuilder extends io.fabric8.istio.api.networking.v1beta1.ServerTLSSettingsFluentImpl<io.fabric8.istio.api.networking.v1beta1.ServerTLSSettingsBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.istio.api.networking.v1beta1.ServerTLSSettings,io.fabric8.istio.api.networking.v1beta1.ServerTLSSettingsBuilder>{
  public ServerTLSSettingsBuilder() {
    this(false);
  }
  public ServerTLSSettingsBuilder(java.lang.Boolean validationEnabled) {
    this(new ServerTLSSettings(), validationEnabled);
  }
  public ServerTLSSettingsBuilder(io.fabric8.istio.api.networking.v1beta1.ServerTLSSettingsFluent<?> fluent) {
    this(fluent, false);
  }
  public ServerTLSSettingsBuilder(io.fabric8.istio.api.networking.v1beta1.ServerTLSSettingsFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ServerTLSSettings(), validationEnabled);
  }
  public ServerTLSSettingsBuilder(io.fabric8.istio.api.networking.v1beta1.ServerTLSSettingsFluent<?> fluent,io.fabric8.istio.api.networking.v1beta1.ServerTLSSettings instance) {
    this(fluent, instance, false);
  }
  public ServerTLSSettingsBuilder(io.fabric8.istio.api.networking.v1beta1.ServerTLSSettingsFluent<?> fluent,io.fabric8.istio.api.networking.v1beta1.ServerTLSSettings instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withCaCertificates(instance.getCaCertificates()); 
    fluent.withCipherSuites(instance.getCipherSuites()); 
    fluent.withCredentialName(instance.getCredentialName()); 
    fluent.withHttpsRedirect(instance.getHttpsRedirect()); 
    fluent.withMaxProtocolVersion(instance.getMaxProtocolVersion()); 
    fluent.withMinProtocolVersion(instance.getMinProtocolVersion()); 
    fluent.withMode(instance.getMode()); 
    fluent.withPrivateKey(instance.getPrivateKey()); 
    fluent.withServerCertificate(instance.getServerCertificate()); 
    fluent.withSubjectAltNames(instance.getSubjectAltNames()); 
    fluent.withVerifyCertificateHash(instance.getVerifyCertificateHash()); 
    fluent.withVerifyCertificateSpki(instance.getVerifyCertificateSpki()); 
    this.validationEnabled = validationEnabled; 
  }
  public ServerTLSSettingsBuilder(io.fabric8.istio.api.networking.v1beta1.ServerTLSSettings instance) {
    this(instance,false);
  }
  public ServerTLSSettingsBuilder(io.fabric8.istio.api.networking.v1beta1.ServerTLSSettings instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withCaCertificates(instance.getCaCertificates()); 
    this.withCipherSuites(instance.getCipherSuites()); 
    this.withCredentialName(instance.getCredentialName()); 
    this.withHttpsRedirect(instance.getHttpsRedirect()); 
    this.withMaxProtocolVersion(instance.getMaxProtocolVersion()); 
    this.withMinProtocolVersion(instance.getMinProtocolVersion()); 
    this.withMode(instance.getMode()); 
    this.withPrivateKey(instance.getPrivateKey()); 
    this.withServerCertificate(instance.getServerCertificate()); 
    this.withSubjectAltNames(instance.getSubjectAltNames()); 
    this.withVerifyCertificateHash(instance.getVerifyCertificateHash()); 
    this.withVerifyCertificateSpki(instance.getVerifyCertificateSpki()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.istio.api.networking.v1beta1.ServerTLSSettingsFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.istio.api.networking.v1beta1.ServerTLSSettings build() {
    ServerTLSSettings buildable = new ServerTLSSettings(fluent.getCaCertificates(),fluent.getCipherSuites(),fluent.getCredentialName(),fluent.getHttpsRedirect(),fluent.getMaxProtocolVersion(),fluent.getMinProtocolVersion(),fluent.getMode(),fluent.getPrivateKey(),fluent.getServerCertificate(),fluent.getSubjectAltNames(),fluent.getVerifyCertificateHash(),fluent.getVerifyCertificateSpki());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ServerTLSSettingsBuilder that = (ServerTLSSettingsBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> istio-model-v1beta1-6.6.1-sources.jar: io/fabric8/istio/api/networking/v1beta1/ServerTLSSettingsBuilder.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ServerTLSSettingsBuilder extends ServerTLSSettingsFluentImpl<ServerTLSSettingsBuilder> implements VisitableBuilder<ServerTLSSettings,ServerTLSSettingsBuilder>{
  public ServerTLSSettingsBuilder() {
    this(false);
  }
  public ServerTLSSettingsBuilder(Boolean validationEnabled) {
    this(new ServerTLSSettings(), validationEnabled);
  }
  public ServerTLSSettingsBuilder(ServerTLSSettingsFluent<?> fluent) {
    this(fluent, false);
  }
  public ServerTLSSettingsBuilder(ServerTLSSettingsFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ServerTLSSettings(), validationEnabled);
  }
  public ServerTLSSettingsBuilder(ServerTLSSettingsFluent<?> fluent,ServerTLSSettings instance) {
    this(fluent, instance, false);
  }
  public ServerTLSSettingsBuilder(ServerTLSSettingsFluent<?> fluent,ServerTLSSettings instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withCaCertificates(instance.getCaCertificates()); 
    fluent.withCipherSuites(instance.getCipherSuites()); 
    fluent.withCredentialName(instance.getCredentialName()); 
    fluent.withHttpsRedirect(instance.getHttpsRedirect()); 
    fluent.withMaxProtocolVersion(instance.getMaxProtocolVersion()); 
    fluent.withMinProtocolVersion(instance.getMinProtocolVersion()); 
    fluent.withMode(instance.getMode()); 
    fluent.withPrivateKey(instance.getPrivateKey()); 
    fluent.withServerCertificate(instance.getServerCertificate()); 
    fluent.withSubjectAltNames(instance.getSubjectAltNames()); 
    fluent.withVerifyCertificateHash(instance.getVerifyCertificateHash()); 
    fluent.withVerifyCertificateSpki(instance.getVerifyCertificateSpki()); 
    this.validationEnabled = validationEnabled; 
  }
  public ServerTLSSettingsBuilder(ServerTLSSettings instance) {
    this(instance,false);
  }
  public ServerTLSSettingsBuilder(ServerTLSSettings instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withCaCertificates(instance.getCaCertificates()); 
    this.withCipherSuites(instance.getCipherSuites()); 
    this.withCredentialName(instance.getCredentialName()); 
    this.withHttpsRedirect(instance.getHttpsRedirect()); 
    this.withMaxProtocolVersion(instance.getMaxProtocolVersion()); 
    this.withMinProtocolVersion(instance.getMinProtocolVersion()); 
    this.withMode(instance.getMode()); 
    this.withPrivateKey(instance.getPrivateKey()); 
    this.withServerCertificate(instance.getServerCertificate()); 
    this.withSubjectAltNames(instance.getSubjectAltNames()); 
    this.withVerifyCertificateHash(instance.getVerifyCertificateHash()); 
    this.withVerifyCertificateSpki(instance.getVerifyCertificateSpki()); 
    this.validationEnabled = validationEnabled; 
  }
  ServerTLSSettingsFluent<?> fluent;
  Boolean validationEnabled;
  public ServerTLSSettings build() {
    ServerTLSSettings buildable = new ServerTLSSettings(fluent.getCaCertificates(),fluent.getCipherSuites(),fluent.getCredentialName(),fluent.getHttpsRedirect(),fluent.getMaxProtocolVersion(),fluent.getMinProtocolVersion(),fluent.getMode(),fluent.getPrivateKey(),fluent.getServerCertificate(),fluent.getSubjectAltNames(),fluent.getVerifyCertificateHash(),fluent.getVerifyCertificateSpki());
    return buildable;
  }
  
}
